summaryrefslogtreecommitdiffstats
path: root/src/bookmarksdlg.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitb80425fab482ed78785a18ff6febd33f9e1988ac (patch)
treedf0665fd3580b654d0317cb0f291c67bd62b2cb9 /src/bookmarksdlg.cpp
parent1c143fef35113fa8fe63b60a67aa4b2ff81b3396 (diff)
downloadkbookreader-b80425fab482ed78785a18ff6febd33f9e1988ac.tar.gz
kbookreader-b80425fab482ed78785a18ff6febd33f9e1988ac.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kbookreader@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/bookmarksdlg.cpp')
-rw-r--r--src/bookmarksdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/bookmarksdlg.cpp b/src/bookmarksdlg.cpp
index 772664b..5a9907d 100644
--- a/src/bookmarksdlg.cpp
+++ b/src/bookmarksdlg.cpp
@@ -28,16 +28,16 @@
#include "bookmarksdlg.h"
/*
* Constructs a BookmarksDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-BookmarksDlg::BookmarksDlg(const Bookmarks& bms, TQWidget* tqparent,
+BookmarksDlg::BookmarksDlg(const Bookmarks& bms, TQWidget* parent,
const char* name, bool modal, WFlags fl)
- : TQDialog(tqparent, name, modal, fl),
+ : TQDialog(parent, name, modal, fl),
m_bookmarks(bms)
{
if ( !name )
@@ -28,16 +28,16 @@
#include "bookmarksdlg.h"
/*
- * Constructs a BookmarksDlg as a child of 'tqparent', with the
+ * Constructs a BookmarksDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*